richardview package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   richardview.built_in_widgets
   richardview.majumdar_lab_widgets

Submodules
----------

richardview.dashboard module
----------------------------

.. automodule:: richardview.dashboard
   :members:
   :undoc-members:
   :show-inheritance:

richardview.generic\_serial\_emulator module
--------------------------------------------

.. automodule:: richardview.generic_serial_emulator
   :members:
   :undoc-members:
   :show-inheritance:

richardview.generic\_widget module
----------------------------------

.. automodule:: richardview.generic_widget
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: richardview
   :members:
   :undoc-members:
   :show-inheritance:
